@@ -1,7 +1,7 @@
 #ifndef __DICT_H_
 #define __DICT_H_
 
-/* $Id: dict.h,v 1.6 2000/05/18 00:31:33 hovinen Exp $ */
+/* $Id: dict.h,v 1.9 2003/05/19 11:08:13 gman Exp $ */
 
 /*
  *  Bradford Hovinen <hovinen@udel.edu>
@@ -20,7 +20,7 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 
-#define DICT_DEFAULT_SERVER "www.dict.org"
+#define DICT_DEFAULT_SERVER "dict.org"
 #define DICT_DEFAULT_PORT   2628
 
 #define READ_BUF_LEN 4096
@@ -95,6 +95,7 @@ typedef struct _dict_command_t {
 				     gpointer data);
     
     gchar        *db_name;
+    gchar	 *db_full_name;
     GString      *def;
     
     gchar        *search_term;          /* Parameters used in current search */
@@ -111,8 +112,15 @@ typedef struct _dict_command_t {
     gpointer     user_data;               /* Data to pass along to callbacks */
 } dict_command_t;
 
+gboolean have_ipv6(void);
+
 typedef struct _dict_context_t {
+#ifdef ENABLE_IPV6
+    struct sockaddr_storage sockaddr;
+    struct addrinfo *host6info;
+#else
     struct sockaddr_in sockaddr;
+#endif
     struct hostent *hostinfo;
     char           *hostname;
     
